@@ -7,15 +7,20 @@ SERVICES = [
     "cloudamqp",
     "cloudflare",
     "codecov",
+    "confluence",
+    "coveralls",
     "digitalocean",
     "discord",
     "docker",
+    "gandi",
     "github",
     "gitlab",
     "invision",
+    "jira",
     "heroku",
     "mailgun",
     "npm",
+    "nylas",
     "pagerduty",
     "personio",
     "pypi",
@@ -27,7 +32,10 @@ SERVICES = [
     "slack",
     "sparkpost",
     "travis",
+    "trello",
     "twilio",
+    "twitter",
+    "zoom",
 ]
 
 __all__ = [SERVICES]
